=======================
The ``getlino`` package
=======================




A command-line tool to install and configure Lino in different environments.

Note: If you **just want to install** Lino, then this repository is **not for
you**. You want to read the  `Lino book <http://www.lino-framework.org>`__
instead. This repository is for people who want to help with developing the tool
that you use to install Lino.

The central project homepage is http://getlino.lino-framework.org

    
